"""Top-level package for httpx-auth-awssigv4."""

from .auth import SigV4Auth

__author__ = """Mohan Muppidi"""
__email__ = 'mkumar2301@gmail.com'
__version__ = '0.1.4'
